==> bval-parent-1.1.2-source-release.zip: bval-parent-1.1.2/bval-jsr/src/test/java/org/apache/bval/jsr/groups/inheritance/BillableUser.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.apache.bval.jsr.groups.inheritance;

import org.apache.bval.jsr.groups.Billable;
import org.apache.bval.jsr.groups.BillableCreditCard;

import javax.validation.constraints.NotNull;
import javax.validation.groups.Default;

/**
 * Description: <br/>
 */
public class BillableUser {
    @NotNull
    private String firstname;

    @NotNull(groups = Default.class)
    private String lastname;

    @NotNull(groups = { Billable.class })
    private BillableCreditCard defaultCreditCard;

    public String getFirstname() {
        return firstname;
    }

    public void setFirstname(String firstname) {
        this.firstname = firstname;
    }

    public String getLastname() {
        return lastname;
    }

    public void setLastname(String lastname) {
        this.lastname = lastname;
    }

    public BillableCreditCard getDefaultCreditCard() {
        return defaultCreditCard;
    }

    public void setDefaultCreditCard(BillableCreditCard defaultCreditCard) {
        this.defaultCreditCard = defaultCreditCard;
    }
}

==> bval-parent-3.0.2-source-release.zip: bval-parent-3.0.2/bval-jsr/src/test/java/org/apache/bval/jsr/groups/inheritance/BillableUser.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.apache.bval.jsr.groups.inheritance;

import org.apache.bval.jsr.groups.Billable;
import org.apache.bval.jsr.groups.BillableCreditCard;

import jakarta.validation.constraints.NotNull;
import jakarta.validation.groups.Default;

/**
 * Description: <br/>
 */
public class BillableUser {
    @NotNull
    private String firstname;

    @NotNull(groups = Default.class)
    private String lastname;

    @NotNull(groups = { Billable.class })
    private BillableCreditCard defaultCreditCard;

    public String getFirstname() {
        return firstname;
    }

    public void setFirstname(String firstname) {
        this.firstname = firstname;
    }

    public String getLastname() {
        return lastname;
    }

    public void setLastname(String lastname) {
        this.lastname = lastname;
    }

    public BillableCreditCard getDefaultCreditCard() {
        return defaultCreditCard;
    }

    public void setDefaultCreditCard(BillableCreditCard defaultCreditCard) {
        this.defaultCreditCard = defaultCreditCard;
    }
}
